VideoTrack class

Annotations

Constructors

VideoTrack({required String id, int? width, int? height, int? bitrate, String? label, bool isSelected = false})
const
VideoTrack.fromJson(Map<String, dynamic> json)
factory

Properties

bitrate int?
final
hashCode int
The hash code for this object.
no setteroverride
height int?
final
id String
final
isSelected bool
final
label String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override