EventService class

Constructors

EventService()
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
logStream Stream<String>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addLog(String log) → void
dispose() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited