Viewer class

Constructors

Viewer({required String id, required String username})

Properties

dc ↔ RTCDataChannel?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
id String
final
isMuted bool
getter/setter pair
pc ↔ RTCPeerConnection?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
username String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited