DanmakuMessage class

Annotations

Constructors

DanmakuMessage({required String id, required String content, required String sender, bool isFromBroadcaster = false, bool isSystem = false})
const

Properties

content String
final
hashCode int
The hash code for this object.
no setteroverride
id String
final
isFromBroadcaster bool
final
isSystem bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sender String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
override